==> blanco.plugin.message_0.4.0-src.zip: blancoMessagePlugin/src/blanco/plugin/message/wizards/BlancoMessageWizardPage4.java <==
/*
 * blanco Framework
 * Copyright (C) 2004-2006 IGA Tosiki
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 */
package blanco.plugin.message.wizards;

import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;

import blanco.message.BlancoMessageConstants;
import blanco.message.resourcebundle.BlancoMessageResourceBundle;

/**
 * vOCEBU[h̃y[W̃NXłB
 * 
 * @author IGA Tosiki
 */
public class BlancoMessageWizardPage4 extends WizardPage {
    private static final BlancoMessageResourceBundle fBundle = new BlancoMessageResourceBundle();

    public BlancoMessageWizardPage4(ISelection selection) {
        super("wizardPage");
        setTitle(BlancoMessageConstants.PRODUCT_NAME + "vOCɊ֘AtH_");
    }

    public void createControl(Composite parent) {
        GridLayout gridLayout = new GridLayout();
        gridLayout.numColumns = 1;

        Composite container = new Composite(parent, SWT.NULL);
        container.setLayout(gridLayout);

        new Label(container, SWT.NONE)
                .setText(BlancoMessageConstants.PRODUCT_NAME
                        + "vOCɊ֘AtH_͉L̂ƂłB");
        new Label(container, SWT.NONE).setText("  1.\[XtH_ (tH_ src 𐄏)");
        new Label(container, SWT.NONE)
                .setText("    \[XtH_ݒ(쐬)邱Ƃ܂B");
        new Label(container, SWT.NONE).setText("  2.^fBNg (tH_ meta"
                + BlancoMessageConstants.TARGET_SUBDIRECTORY + " ܂)");
        new Label(container, SWT.NONE).setText("    "
                + fBundle.getMetafileDisplayname() + "i[܂B");
        new Label(container, SWT.NONE)
                .setText("  3.e|fBNg (tH_ tmp ƂȂ܂)");
        new Label(container, SWT.NONE)
                .setText("  4.\[XR[hfBNg (tH_ blanco/main(Java), blanco.cs/main(C#.NET), blanco.js/main(JavaScript) ƂȂ܂)");

        setControl(container);
    }
}

==> blanco.plugin.message_0.4.1-src.zip: blancoMessagePlugin/src/blanco/plugin/message/wizards/BlancoMessageWizardPage4.java <==
/*
 * blanco Framework
 * Copyright (C) 2004-2006 IGA Tosiki
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 */
package blanco.plugin.message.wizards;

import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;

import blanco.message.BlancoMessageConstants;
import blanco.message.resourcebundle.BlancoMessageResourceBundle;

/**
 * vOCEBU[h̃y[W̃NXłB
 * 
 * @author IGA Tosiki
 */
public class BlancoMessageWizardPage4 extends WizardPage {
    private static final BlancoMessageResourceBundle fBundle = new BlancoMessageResourceBundle();

    public BlancoMessageWizardPage4(ISelection selection) {
        super("wizardPage");
        setTitle(BlancoMessageConstants.PRODUCT_NAME + "vOCɊ֘AtH_");
    }

    public void createControl(Composite parent) {
        GridLayout gridLayout = new GridLayout();
        gridLayout.numColumns = 1;

        Composite container = new Composite(parent, SWT.NULL);
        container.setLayout(gridLayout);

        new Label(container, SWT.NONE)
                .setText(BlancoMessageConstants.PRODUCT_NAME
                        + "vOCɊ֘AtH_͉L̂ƂłB");
        new Label(container, SWT.NONE).setText("  1.\[XtH_ (tH_ src 𐄏)");
        new Label(container, SWT.NONE)
                .setText("    \[XtH_ݒ(쐬)邱Ƃ܂B");
        new Label(container, SWT.NONE).setText("  2.^fBNg (tH_ meta"
                + BlancoMessageConstants.TARGET_SUBDIRECTORY + " ܂)");
        new Label(container, SWT.NONE).setText("    "
                + fBundle.getMetafileDisplayname() + "i[܂B");
        new Label(container, SWT.NONE)
                .setText("  3.e|fBNg (tH_ tmp ƂȂ܂)");
        new Label(container, SWT.NONE).setText("  4.ꂽ\[XR[hi[tH_");
        new Label(container, SWT.NONE).setText("    Eblanco/main (Java)");
        new Label(container, SWT.NONE).setText("    Eblanco.cs/main (C#.NET)");
        new Label(container, SWT.NONE)
                .setText("    Eblanco.js/main(JavaScript)");
        new Label(container, SWT.NONE).setText("    Eblanco.vb/main (VB.NET)");
        new Label(container, SWT.NONE).setText("    Eblanco.php/main (PHP)");
        new Label(container, SWT.NONE).setText("    Eblanco.ruby/main (Ruby)");
        new Label(container, SWT.NONE)
                .setText("    Eblanco.python/main (Python)");

        setControl(container);
    }
}
